require File.expand_path('../../extenders/comment_extender', __FILE__)
require File.expand_path('../track_block', __FILE__)
require File.expand_path('../block_avatar', __FILE__)

class CommentOrigin < ActiveRecord::Base
  extend CommentExtender

	# 评论 分表 根据track_id
  self.table_name = 'tb_comment' 

  attr_accessible :uid, :nickname, :avatar_path, :upload_source,
  								:track_id, :track_uid, :track_upload_source, :track_nickname, :track_title, :track_duration, :track_created_at, :track_avatar_path,
  								:second, :content, :parent_id, 
  								:play_path, :play_path_32, :play_path_64, :play_path_128,
                  :user_source, :cover_path, :block, :audio_path
  
  # uid nickname avatar_path --- 用户id 昵称 头像地址
  # upload_source --- 发表自 1:iphone /2:电脑 /3:android
  # track_id track_uid track_nickname track_title --- 声音id uid 昵称 标题
  # track_upload_source --- 声音上传源 1:iphone /2:电脑 /3:android
  # track_duration track_created_at track_avatar_path --- 声音时长 创建时间 头像
  # second content parent_id --- 秒 内容 父id
  # play_path play_path_32 play_path_64 play_path_128 --- 声音播放地址
  # user_source --- 声音来源 1:原创/2:采集
  # cover_path --- 声音封面
  # block --- 在第几块
  # audio_path --- 语音地址

  validates :track_id, presence: true

  belongs_to :track_origin

  before_save do |r|
    unless r.id
      r.id = Comment.next_id
    end

    if r.second and r.second >= 0
      tb = TrackBlock.shard(r.track_id).where(track_id: r.track_id).first
      if tb
         # 加分块计数
        tb.increase_by_second(r.second)
        # 加彩虹块头像
        bidx = tb.get_block_idx_by_second(r.second)
        if bidx
          avatars = BlockAvatar.shard(r.track_id).where(track_id: r.track_id, block_id: bidx)
          if avatars.count > 0 and avatars.count >= 30 / tb.blocks
            avatars.first.destroy
          end
          BlockAvatar.shard(r.track_id).create(track_id: r.track_id, comment_id: r.id, block_id: bidx, 
            uid: r.uid, avatar_path: r.avatar_path)

          r.block = bidx
        end
      end
    end
  end

  after_destroy do |r| 
    if r.second and r.second >= 0
      tb = TrackBlock.shard(r.track_id).where(track_id: r.track_id).first
      if tb
        # 减分块计数
        tb.increase_by_second(r.second, -1)
        # 删掉对应彩虹块头像，再补一张
        if r.block
          avatar = BlockAvatar.shard(r.track_id).where(track_id: r.track_id, block_id: r.block, comment_id: r.id).first
          if avatar
            avatar.destroy

            ba0 = BlockAvatar.shard(r.track_id).where(track_id: r.track_id, block_id: r.block).first
            if ba0
              alter = Comment.shard(r.track_id).where('track_id = ? and block = ? and id < ?', r.track_id, r.block, ba0.comment_id).last
            else
              alter = Comment.shard(r.track_id).where('track_id = ? and block = ?', r.track_id, r.block).last
            end
            if alter
              alter_bidx = tb.get_block_idx_by_second(alter.second)
              BlockAvatar.shard(r.track_id).create(track_id: alter.track_id, comment_id: alter.id, block_id: alter_bidx, 
                uid: alter.uid, avatar_path: alter.avatar_path)
            end
          end
        end
      end
    end

  end

  def to_topic_hash
    {
      created_at: self.created_at,
      updated_at: self.updated_at,
      id: self.id,
      uid: self.uid,
      nickname: self.nickname,
      avatar_path: self.avatar_path,
      track_id: self.track_id,
      track_uid: self.track_uid,
      track_nickname: self.track_nickname,
      track_title: self.track_title,
      track_duration: self.track_duration,
      track_created_at: self.track_created_at,
      track_avatar_path: self.track_avatar_path,
      second: self.second,
      parent_id: self.parent_id,
      content: self.content,
      play_path: self.play_path,
      play_path_32: self.play_path_32,
      play_path_64: self.play_path_64,
      play_path_128: self.play_path_128,
      user_source: self.user_source,
      cover_path: self.cover_path
    }
  end
  
end
