require File.expand_path('../../extenders/favorite_album_extender', __FILE__)
require File.expand_path('../track_set', __FILE__)
require File.expand_path('../lover_album', __FILE__)

class FavoriteAlbumOrigin < ActiveRecord::Base
	extend FavoriteAlbumExtender

	# 收藏专辑 根据uid分表
	self.table_name = 'tb_favorite_album'

	attr_accessible :uid,
					:nickname,
					:avatar_path,
					:album_id,
					:album_uid,
					:album_nickname,
					:album_avatar_path,
					:op_type,
					:user_source,
					:is_crawler,
					:title,
					:tags,
					:intro,
					:cover_path,
					:music_category, 
					:album_created_at,
					:category_id,
					:created_at,
					:updated_at,
					:upload_source 

	# uid nickname avatar_path --- 用户id 昵称 头像
	# album_id album_uid album_nickname album_avatar_path --- 专辑id 用户id 昵称 头像
	# op_type --- 专辑上传类型 1:自己传的 /2:转发
	# user_source --- 专辑来源 1:原创 /2:采集
	# is_crawler --- 专辑 是否爬虫
	# title tags intro cover_path --- 专辑标题 标签 简介 封面
	# music_category --- 专辑 音乐归类
	# album_created_at --- 专辑创建时间
	# category_id --- 专辑分类id
	# upload_source --- 专辑上传自 1:iphone/2:电脑/3:android

	validates :uid, presence: true

	before_save do |r|
    unless r.id
      r.id = FavoriteAlbum.next_id
    end

    album = TrackSet.fetch(r.album_id)
    if album
      r.album_uid = album.uid
      r.album_nickname = album.nickname 
      r.album_avatar_path = album.avatar_path
      r.title = album.title
      r.tags = album.tags
      r.intro = album.intro
      r.cover_path = album.cover_path
      r.music_category = album.music_category
      r.album_created_at = album.created_at
      r.category_id = album.category_id
      r.op_type = album.op_type
      r.user_source = album.user_source
      r.is_crawler = album.is_crawler
    end

    true
	end

	after_save do |r|
		hash = r.attributes
		hash.delete_if{|k,v| %w(id created_at updated_at).include? k }

    lover = LoverAlbum.shard(r.album_id).where(uid: r.uid, album_id: r.album_id).first
		unless lover
		  # 创建
		  lover = LoverAlbum.shard(r.album_id).new
		end
    lover.id = r.id
		lover.update_attributes(hash)
	end

	after_destroy do |r|
    lover = LoverAlbum.shard(r.album_id).where(uid: r.uid, album_id: r.album_id).first
		lover.destroy if lover
	end

end
