require File.expand_path('../../extenders/favorite_extender', __FILE__)
require File.expand_path('../track_in_record', __FILE__)
require File.expand_path('../lover', __FILE__)

class FavoriteOrigin < ActiveRecord::Base
  extend FavoriteExtender

	# 喜欢声音 根据uid分表
  self.table_name = 'tb_favorite' 

  attr_accessible :is_public, :upload_source,
  								:uid, :nickname, :avatar_path,
  								:track_id, :track_uid, :track_upload_source, :track_nickname, :track_avatar_path, :track_duration,
                  :user_source, :category_id,
  								:title, :intro,
  								:duration,
  								:download_path,
                  :play_path, :play_path_32, :play_path_64, :play_path_128,
  								:cover_path, 
  								:cover_path_small, :cover_path_middle, :cover_path_large, :cover_path_wide,
  								:cover_path_60, :cover_path_86, :cover_path_640,  
                  :tags,  
                  :allow_download, :allow_comment,
                  :track_created_at, :track_updated_at,
                  :album_id, :album_title, :album_cover_path, :is_v, 
                  :waveform, :upload_id
  
  # is_public --- 是否公开
  # upload_source --- 操作自 1:iphone /2:电脑 /3:android
  # uid nickname avatar_path --- 用户id 昵称 头像地址
  # track_id track_uid track_nickname track_avatar_path --- 声音id uid 昵称 发布者头像
  # track_upload_source --- 声音上传自 1:iphone /2:电脑 /3:android
  # track_duration --- 声音时长
  # user_source --- 声音来源 1:原创/2:采集
  # category_id --- 声音分类id
  # title intro --- 声音标题 简介
  # duration --- 声音时长
  # download_path --- 声音下载地址
  # play_path play_path_32 play_path_64 play_path_128 --- 播放地址原 32Kbps 64Kbps 128Kbps
  # cover_path --- 声音封面路径原
  # cover_path_small cover_path_middle cover_path_large cover_path_wide --- 未使用 50x50 100x100 180x180 400x300 
  # cover_path_60 cover_path_86 cover_path_640 --- 60x60 86x86 640x640
  # tags --- 声音标签
  # allow_download allow_comment --- 允许下载 允许评论
  # track_created_at track_updated_at --- 声音创建时间 更新时间
  # album_id album_title album_cover_path --- 专辑id 标题 封面
  # is_v --- 声音作者是否加V
  # waveform upload_id --- 声音波形 上传号

  validates :uid, presence: true

  before_save do |r|
    unless r.id
      r.id = Favorite.next_id
    end

    tir = TrackInRecord.fetch(r.track_id)
    if tir
      r.is_public = tir.is_public
      r.track_uid = tir.uid
      r.track_nickname = tir.nickname
      r.track_avatar_path = tir.avatar_path
      r.track_duration = tir.duration
      r.title = tir.title
      r.intro = tir.intro
      r.duration = tir.duration
      r.cover_path = tir.cover_path
      r.tags = tir.tags
      r.intro = tir.intro
      r.play_path = tir.play_path
      r.play_path_32 = tir.play_path_32
      r.play_path_64 = tir.play_path_64
      r.play_path_128 = tir.play_path_128
      r.track_created_at = tir.created_at
      r.allow_download = tir.allow_download
      r.allow_comment = tir.allow_comment
      r.download_path = tir.download_path
      r.album_id = tir.album_id
      r.album_title = tir.album_title
      r.album_cover_path = tir.album_cover_path
      r.category_id = tir.category_id
      r.user_source = tir.user_source
    end
  end

  after_save do |r|
    hash = r.attributes
    hash.delete_if{|k,v| %w(id created_at updated_at).include? k }

    lover = Lover.shard(r.track_id).where(uid: r.uid, track_id: r.track_id).first
    unless lover
      # 创建
      lover = Lover.shard(r.track_id).new
    end
    lover.id = r.id
    lover.update_attributes(hash)
  end

  after_destroy do |r|
    lover = Lover.shard(r.track_id).where(uid: r.uid, track_id: r.track_id).first
    lover.destroy if lover
  end

  def to_topic_hash
    {
      created_at: self.created_at,
      updated_at: self.updated_at,
      id: self.id,
      uid: self.uid,
      nickname: self.nickname,
      avatar_path: self.avatar_path,
      track_id: self.track_id,
      track_uid: self.track_uid,
      track_nickname: self.track_nickname,
      track_avatar_path: self.track_avatar_path,
      track_duration: self.track_duration,
      user_source: self.user_source,
      category_id: self.category_id,
      tags: self.tags,
      title: self.title,
      intro: self.intro,
      cover_path: self.cover_path,
      duration: self.duration,
      download_path: self.download_path,
      play_path: self.play_path,
      play_path_128: self.play_path_128,
      play_path_64: self.play_path_64,
      play_path_32: self.play_path_32,
      track_created_at: self.track_created_at,
      allow_download: self.allow_download,
      allow_comment: self.allow_comment,
      album_id: self.album_id,
      album_title: self.album_title,
      album_cover_path: self.album_cover_path
    }
  end

end
