require File.expand_path('../../extenders/following_extender', __FILE__)
require File.expand_path('../follower', __FILE__)

class FollowingOrigin < ActiveRecord::Base
  extend FollowingExtender

	# 关注人 分表 根据 uid > followings | following_uid > followers
  self.table_name = 'tb_follow' 

  attr_accessible :uid, :following_uid,
                  :nickname, :avatar_path, 
                  :avatar_path_small, :avatar_path_middle, :avatar_path_large, 
                  :personal_signature, 
                  :country, :province, :city, :town,
                  :following_nickname, :following_avatar_path, 
                  :following_avatar_path_small, :following_avatar_path_middle, :following_avatar_path_large, 
                  :following_personal_signature, 
                  :following_country, :following_province, :following_city, :following_town, :following_is_v,
                  :is_blocked, :is_public, :is_mutual,
                  :following_group_id, :following_group_title, :is_auto_download, :is_auto_push
  
  # uid nickname avatar_path personal_signature --- 用户id 昵称 头像 签名
  # avatar_path_small avatar_path_middle avatar_path_large --- 未使用
  # country province city town --- 用户所在地
  # following_uid following_nickname following_avatar_path following_personal_signature --- 关注用户id 昵称 头像 签名
  # following_avatar_path_small following_avatar_path_middle following_avatar_path_large --- 未使用
  # following_country following_province following_city following_town --- 关注用户所在地
  # following_is_v --- 关注用户是否加V
  # is_blocked --- 是否拉黑
  # is_public --- 是否公开
  # is_mutual --- 是否相互关注                
  # following_group_id --- 未使用
  # following_group_title --- 未使用
  # is_auto_download --- 未使用
  # is_auto_push --- 对方上传了一个声音是否推提醒

  validates :uid, presence: true

  before_save do |r|
    unless r.id
      r.id = Following.next_id
    end
  end

  after_save do |r|
    hash = r.attributes
    hash.delete_if{|k,v| %w(id created_at updated_at).include? k }

    follower = Follower.shard(r.following_uid).where(uid: r.uid, following_uid: r.following_uid).first

    unless follower
      # 创建
      follower = Follower.shard(r.following_uid).new
    end
    follower.id = r.id
    follower.update_attributes(hash)
  end

  after_destroy do |r|
    # 关注数 - 1
    Following.decr_user_followings_count(r.uid)

    follower = Follower.shard(r.following_uid).where(uid: r.uid, following_uid: r.following_uid).first

    if follower
      follower.destroy 
      # 粉丝数 - 1
      Following.decr_user_followers_count(follower.following_uid)
    end
  end

end
