require File.expand_path('../../extenders/following_tag_extender', __FILE__)
require File.expand_path('../follower_tag', __FILE__)

class FollowingTagOrigin < ActiveRecord::Base
  extend FollowingTagExtender

	# 关注标签 根据uid分表
  self.table_name = 'tb_follow_tag' 

  attr_accessible :uid, :tag_id,
                  :tname, :cover_path
  
  # uid --- 用户id
  # tag_id --- 未使用
  # tname --- 标签
  # cover_path --- 标签图标

  validates :uid, presence: true

  before_save do |r|
    unless r.id
      r.id = FollowingTag.next_id
    end
  end

  after_save do |r|
    hash = r.attributes
    hash.delete_if{|k,v| %w(id created_at updated_at).include? k }

    follower_tag = FollowerTag.shard(r.tname).where(id: r.id).first
    unless follower_tag
      # 创建
      follower_tag = FollowerTag.shard(r.tname).new
      follower_tag.id = r.id
      follower_tag.created_at = r.created_at
      follower_tag.updated_at = r.updated_at
    end
    follower_tag.update_attributes(hash)
  end

  after_destroy do |r|
    # 删副本
    follower_tag = FollowerTag.shard(r.tname).where(id: r.id).first
    follower_tag.destroy if follower_tag
  end

  def to_topic_hash
    {
      created_at: self.created_at,
      updated_at: self.updated_at,
      id: self.id,
      uid: self.uid,
      tag_id: self.tag_id,
      tname: self.tname,
      cover_path: self.cover_path
    }
  end

end
