require File.expand_path('../../extenders/track_block_extender', __FILE__)

class TrackBlockOrigin < ActiveRecord::Base
  extend TrackBlockExtender

  TRACK_MAX_BLOCKS = 30 # 播放彩条分块
  MIN_SECONDS_PER_BLOCK = 2 # 彩条分块每块默认几秒

	# 声音块 根据track_id分表
  self.table_name = 'tb_track_block'

  attr_accessible :track_id, 
  								:duration, 
  								:blocks, 
  								:flags,
							  	:b0, :b1, :b2, :b3, :b4, :b5, :b6, :b7, :b8, :b9, :b10,
							  	:b11, :b12, :b13, :b14, :b15, :b16, :b17, :b18, :b19, :b20,
							  	:b21, :b22, :b23, :b24, :b25, :b26, :b27, :b28, :b29

  # track_id --- 声音id
  # duration --- 时长
  # blocks --- 块数
  # flags --- 逐块起始秒数 0.000,1.234,5.678
  # b｛n｝ --- 第n块评论数
  
  validates :track_id, presence: true

  def get_block_idx_by_second(second)
    if second
      second = second.to_i
      next_flag = self.flags.split(',').map{|s| s.to_f}.index{|x| x > second}
      return next_flag ? next_flag - 1 : self.blocks - 1
    end

    nil
  end

  # 更新评论数
  def increase_by_second(second, inc = 1)
    idx = self.get_block_idx_by_second(second)
    if idx
      col = "b#{idx}"
      count = self.send(col) + inc
      self.update_attributes(col.to_sym => (count >= 0 ? count : 0))
    end
  end

  before_save do |r|
    unless r.id
      r.id = TrackBlock.next_id
    end

    # 如果播放时长被赋值，没有块记录，设置块
    if r.duration and r.blocks.nil?
      b = (r.duration / MIN_SECONDS_PER_BLOCK + 1).to_i # 块数
      b = TRACK_MAX_BLOCKS if b > TRACK_MAX_BLOCKS

      sec_per_block = r.duration / b # 每秒长度
      flags = []
      b.times do |i|
        flags << "%5.3f" % (sec_per_block * i)
      end
      
      r.blocks = b
      r.flags = flags.join(',')
    end
  end

end
