require File.expand_path('../../extenders/track_extender', __FILE__)

class TrackOrigin < ActiveRecord::Base
  extend TrackExtender
  # 声音 根据id分表 
  self.table_name = 'tb_track'

  attr_accessible :is_publish,
                  :upload_source, 
                  :uid, :nickname, :avatar_path, :is_v, :human_category_id,
                  :title, :intro, 
                  :user_source, 
                  :category_id, 
                  :duration, 
                  :download_path, 
                  :play_path, :play_path_32, :play_path_64, :play_path_128, 
                  :transcode_state, 
                  :cover_path, 
                  :album_id, :album_title, 
                  :album_cover_path,
                  :tags, :ignore_tags, :extra_tags,
                  :singer, :singer_category, :author, 
                  :composer, :arrangement, :post_production, 
                  :lyric, :lyric_path, 
                  :language, :resinger, :announcer, 
                  :is_public, :access_password, 
                  :allow_download, :allow_comment, 
                  :is_crawler, :inet_aton_ip, :longitude, :latitude,
                  :music_category, :order_num, :is_pick,
                  :rich_intro, :short_intro,
                  :dig_status, :approved_at,
                  :is_deleted,
                  :mp3size, :mp3size_32, :mp3size_64,
                  :created_at, :updated_at, :id, :waveform, :upload_id,
                  :source_url, :status, :explore_height, :download_size
                  
                  
  # is_publish --- 是否发布
  # upload_source --- 上传源 1:iphone/2:电脑/3:android
  # uid nickname is_v avatar_path avatar_path_640 --- 用户id 昵称 头像地址小 大 是否加v
  # title intro short_intro rich_intro --- 标题 简介（不带格式） 短简介（不带格式） 收起的富简介（展开见track_rich.rich_intro）
  # user_source --- 声音来源 1:原创/2:采集
  # category_id --- 分类id
  # duration --- 时长
  # download_path --- 下载地址
  # play_path play_path_32 play_path_64 play_path_128 --- 播放地址原 32Kbps 64Kbps 128Kbps
  # transcode_state --- 转码状态 1:处理中/2:已完成/3:已失败
  # cover_path --- 声音封面
  # cover_path_60 cover_path_86 cover_path_640 --- 未使用
  # album_id album_title --- 专辑id 标题
  # album_cover_path album_cover_path_640 --- 专辑封面路径小 大
  # tags tags_json --- 标签(逗号分隔) 标签json
  # singer singer_category author --- 演唱 歌手类型 作词（作者） 
  # composer arrangement post_production --- 作曲 编曲 后期
  # lyric lyric_path --- 文案/歌词(未使用，见track_rich.lyric) 字幕路径(未使用)
  # language resinger announcer --- 语言 翻唱 播音
  # is_public access_password --- 是否公开 访问密码
  # allow_download allow_comment --- 允许下载 允许评论
  # is_crawler inet_aton_ip  --- 是否爬得 inet_aton过的ip
  # longitude latitude --- 未使用
  # music_category --- 音乐分类 原唱/翻唱/伴奏/小样/K歌/音效
  # order_num --- 排序号
  # is_pick --- 未使用
  # dig_status --- 去发现页状态 0:待审核/1:去发现页/2:不去
  # approved_at --- 去发现页的时间
  # is_deleted --- 是否被删除
  # mp3size --- mp3文件大小
  # upload_id waveform --- 声音文件id 波形图采样数据文件地址
  # source_url --- 视频源地址
  # status --- 声音状态 0: 待审核/1: 已上架/2: 已下架
  # explore_height --- 封面高上限

  validates :title, presence: true

  has_one :human_recommend_category_tag_track
  has_one :human_recommend_track
  has_one :human_recommend_category_track
  belongs_to :category  

  before_save do |r|
    unless r.id
      r.id = Track.next_id
    end
  end

  def to_topic_hash
    {
      created_at: self.created_at,
      updated_at: self.updated_at,
      id: self.id,
      uid: self.uid,
      nickname: self.nickname,
      avatar_path: self.avatar_path,
      is_v: self.is_v,
      human_category_id: self.human_category_id,
      is_public: self.is_public,
      is_publish: self.is_publish,
      user_source: self.user_source,
      category_id: self.category_id,
      tags: self.tags,
      title: self.title,
      intro: self.intro,
      cover_path: self.cover_path,
      duration: self.duration,
      download_path: self.download_path,
      play_path: self.play_path,
      play_path_32: self.play_path_32,
      play_path_64: self.play_path_64,
      play_path_128: self.play_path_128,
      singer: self.singer,
      singer_category: self.singer_category,
      author: self.author,
      composer: self.composer,
      arrangement: self.arrangement,
      post_production: self.post_production,
      lyric: self.lyric,
      lyric_path: self.lyric_path,
      language: self.language,
      resinger: self.resinger,
      announcer: self.announcer,
      access_password: self.access_password,
      allow_download: self.allow_download,
      allow_comment: self.allow_comment,
      is_crawler: self.is_crawler,
      inet_aton_ip: self.inet_aton_ip,
      upload_source: self.upload_source,
      longitude: self.longitude,
      latitude: self.latitude,
      album_id: self.album_id,
      album_title: self.album_title,
      album_cover_path: self.album_cover_path,
      transcode_state: self.transcode_state,
      music_category: self.music_category,
      short_intro: self.short_intro,
      dig_status: self.dig_status,
      approved_at: self.approved_at,
      is_deleted: self.is_deleted,
      mp3size: self.mp3size,
      mp3size_32: self.mp3size_32,
      mp3size_64: self.mp3size_64,
      waveform: self.waveform,
      upload_id: self.upload_id,
      status: self.status
    }
  end

  def is_crawler_disp
    case self.is_crawler
      when true
        '爬虫'
      when false
        '用户'
    end
  end

  def is_publish_disp
    case self.is_publish
      when true
        '审核通过'
      when false
        '审核不通过'
      else
        '审核通过'
    end
  end

  def user_source_disp
    case user_source
      when 1
        '原创'
      when 2
        '采集'
      else
        ''
    end
  end

  def upload_source_disp
    case self.upload_source
      when 1
        'ios'
      when 2
        '电脑'
      when 3
        'android'
    end
  end

  #去发现页状态显示
  def dig_status_disp
    case self.dig_status
    when 0
      '待去'
    when 1
      '去'
    when 2
      '不去'
    end      
  end

  #是否加V
  def is_v_disp
    case self.is_v
    when true
      "是"
    when false
      "否"
    end          
  end

  #审核状态
  def track_status_disp
    case status
    when 0
      "待审核"
    when 1
      "通过"
    when 2
      "不通过"
    end
  end

  
end