require File.expand_path('../../extenders/track_set_extender', __FILE__)

class TrackSetOrigin < ActiveRecord::Base
  extend TrackSetExtender

  # 专辑 根据id分表, id同album.id
  self.table_name = 'tb_album'

  attr_accessible :op_type,
                  :is_publish,
                  :uid, :nickname, :avatar_path, :is_v, :human_category_id,
                  :title, :intro, :short_intro, :rich_intro,
                  :user_source, 
                  :category_id,
                  :cover_path,
                  :tags, :extra_tags,
                  :is_public,
                  :music_category,
                  :tracks_order,
                  :is_crawler,
                  :is_deleted,:created_at, :updated_at, :id,
                  :source_url,
                  :is_records_desc, 
                  :last_uptrack_at, :last_uptrack_id, :last_uptrack_title, :last_uptrack_cover_path, 
                  :status, :dig_status, :is_finished

  # op_type --- 1:自己传的 /2:转发
  # is_publish --- 是否发布
  # uid nickname avatar_path is_v human_category_id --- 用户id 昵称 头像地址 是否加v 用户分类id
  # title intro short_intro rich_intro --- 标题 简介（不带格式） 短简介（不带格式） 收起的富简介（展开见track_set_rich.rich_intro）
  # user_source --- 专辑来源 1:原创/2:采集
  # category_id --- 分类id
  # cover_path --- 专辑专辑封面路径原
  # tags extra_tags --- 标签(逗号分隔) 额外标签
  # is_public --- 是否公开
  # music_category --- 音乐归类
  # tracks_order --- 声音记录id排序 '3,2,1'(非爬虫专辑的排序依据)
  # is_crawler --- 是否爬虫
  # is_deleted --- 是否已删除
  # source_url --- 专辑来源地址
  # is_records_desc --- 真人专辑：新上传声音是否插在第一个, 爬虫专辑：声音记录是否倒序取
  # last_uptrack_at last_uptrack_id last_uptrack_title last_uptrack_cover_path --- 最后更新声音 时间 id 标题 封面
  # status --- 0: 待审核 1: 已通过 2: 已拒绝
  # dig_status --- 去发现页状态 0:待审核/1:去发现页/2:不去

  after_save do |r|
    TrackSet.del_cache(r)
  end

  after_destroy do |r|
    TrackSet.del_cache(r)
  end

  def to_topic_hash
    {
      created_at: self.created_at,
      updated_at: self.updated_at,
      id: self.id,
      uid: self.uid,
      nickname: self.nickname,
      avatar_path: self.avatar_path,
      is_v: self.is_v,
      human_category_id: self.human_category_id,
      is_public: self.is_public,
      is_publish: self.is_publish,
      user_source: self.user_source,
      category_id: self.category_id,
      tags: self.tags,
      title: self.title,
      intro: self.intro,
      cover_path: self.cover_path,
      music_category: self.music_category,
      is_deleted: self.is_deleted,
      status: self.status,
      dig_status: self.dig_status,
      extra_tags: self.extra_tags
    }
  end

  def self.hashlize(obj)
    {
      id: obj.id,
      uid: obj.uid,
      nickname: obj.nickname,
      avatar_path: obj.avatar_path,
      is_v: obj.is_v,
      is_public: obj.is_public,
      is_publish: obj.is_publish,
      user_source: obj.user_source,
      category_id: obj.category_id,
      tags: obj.tags,
      title: obj.title,
      intro: obj.intro,
      cover_path: obj.cover_path,
      created_at: obj.created_at,
      updated_at: obj.updated_at,
      music_category: obj.music_category,
      tracks_order: obj.tracks_order,
      is_crawler: obj.is_crawler,
      rich_intro: obj.rich_intro,
      op_type: obj.op_type,
      short_intro: obj.short_intro,
      is_deleted: obj.is_deleted,
      source_url: obj.source_url,
      is_records_desc: obj.is_records_desc,
      last_uptrack_at: obj.last_uptrack_at,
      last_uptrack_id: obj.last_uptrack_id,
      last_uptrack_title: obj.last_uptrack_title,
      last_uptrack_cover_path: obj.last_uptrack_cover_path,
      status: obj.status,
      dig_status: obj.dig_status,
      human_category_id: obj.human_category_id
    }
  end

  def is_publish_disp
    case self.is_publish
      when true
        '审核通过'
      when false
        '审核不通过'
      else
        '审核通过'
    end
  end

  def user_source_disp
    case user_source
      when 1
        '原创'
      when 2
        '采集'
      else
        ''
    end
  end

  def is_crawler_disp
    case self.is_crawler
      when true
        '爬虫'
      when false
        '用户'
    end
  end

end
